/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package com.jcg.i18n;

import java.util.Locale;

/**
 *
 * @author Kevin
 */
public class DemoLocale
{
    public static void demoDefaults()
    {
        printHeading("Demo default Locales");
        Locale defaultLocale = Locale.getDefault();
        Locale displayDefaultLocale =
            Locale.getDefault(Locale.Category.DISPLAY);
        Locale formatDefaultLocale =
            Locale.getDefault(Locale.Category.FORMAT);
        System.out.println("Default locale: " + defaultLocale.toLanguageTag());
        System.out.println("Default DISPLAY locale: "
            + displayDefaultLocale.toLanguageTag());
        System.out.println("Default FORMAT locale: "
            + formatDefaultLocale.toLanguageTag());
    }

    public static void demoConstructors()
    {
        printHeading("Demo Locale constructors");
        Locale frenchLocale = new Locale("fr");
        Locale brazilianPortuguese = new Locale("pt", "BR");
        Locale valencianCatalan = new Locale("ca", "ES", "VALENCIA");

        System.out.println("Language locale: " + frenchLocale.toLanguageTag());
        System.out.println("Regional locale: "
            + brazilianPortuguese.toLanguageTag());
        System.out.println("Regional locale with variant: "
            + valencianCatalan.toLanguageTag());
    }

    public static void demoBuilder()
    {
        printHeading("Demo Locale.Builder API");
        // Serbian language (Montenegro), Cyrillic script
        Locale serbian = new Locale.Builder()
            .setLanguage("sr")
            .setScript("Cyrl")
            .setRegion("ME")
            .build();

        // Japanese language (Japan), Imperial calendar
        Locale japaneseWithImperialCalendar = new Locale.Builder()
            .setLanguage("ja")
            .setRegion("JP")
            .setUnicodeLocaleKeyword("ca", "Japanese")
            .build();
        System.out.println("Script tag: " + serbian.toLanguageTag());
        System.out.println("Unicode locale extension: "
            + japaneseWithImperialCalendar.toLanguageTag());
    }

    public static void demoForLanguageTag()
    {
        printHeading("Demo Locale.forLanguageTag(String)");
        Locale l1 = Locale.forLanguageTag("ja-JP-u-ca-Japanese");
        Locale l2 = Locale.forLanguageTag("sr-Cyrl-ME");
        System.out.println("l1: " + l1.toLanguageTag());
        System.out.println("l2: " + l2.toLanguageTag());
    }

    public static void demoConstants()
    {
        printHeading("Demo Locale constants");
        System.out.println("Locale.ENGLISH: " + Locale.ENGLISH.toLanguageTag());
        System.out.println("Locale.US: " + Locale.US.toLanguageTag());
        System.out.println("Locale.UK: " + Locale.UK.toLanguageTag());
    }


    public static void demoAccessors()
    {
        printHeading("Demo accessors");
        Locale l = Locale.forLanguageTag("sr-Cyrl-ME");
        System.out.println("Locale: " + l.toLanguageTag());
        System.out.println("Language: \"" + l.getLanguage() + "\"");
        System.out.println("Script: \"" + l.getScript() + "\"");
        System.out.println("Country/region: \"" + l.getCountry() + "\"");
        System.out.println("Variant: \"" + l.getVariant() + "\"");
    }

    public static void demoExtensionAccess()
    {
        printHeading("Demo extensions access");
        Locale l = Locale.forLanguageTag(
            "ja-JP-u-ca-japanese-x-lvariant-JP");
        for (char c : l.getExtensionKeys()) {
            String ext = l.getExtension(c);
            System.out.printf("%c - %s%n", c, ext);
        }
    }

    public static void demoUnicodeExtensionAccess()
    {
        printHeading("Demo Unicode Locale Extension access");
        Locale l = Locale.forLanguageTag("en-US-u-attr1-attr2-ca-japanese-nu-thai");
        System.out.println("Unicode Locale attributes: "
            + String.join(",", l.getUnicodeLocaleAttributes()));
        for (String key : l.getUnicodeLocaleKeys()) {
            String type = l.getUnicodeLocaleType(key);
            System.out.println("Unicode Locale keyword: key=" + key + ", type="
                + type);
        }
    }
    
    public static void demoGetAvailablelLocales(){
        printHeading("Demo getAvailableLocales");
        Locale[] allLocales = Locale.getAvailableLocales();
        for (Locale l : allLocales) {
            System.out.println(l.toLanguageTag() + ": " + l.getDisplayName());
        }
    }

    public static void demoDisplayXXX()
    {
        printHeading("Demo getDisplayXXX() methods");

        Locale usLocale = Locale.forLanguageTag("en-US");
        System.out.printf("Language = %s (%s)%n", usLocale.getLanguage(), usLocale.getDisplayLanguage());
        System.out.printf("Region = %s (%s)%n", usLocale.getCountry(),
            usLocale.getDisplayCountry());
        System.out.printf("Language = %s (%s)%n", usLocale.getLanguage(), usLocale.getDisplayLanguage(Locale.FRENCH));
        System.out.printf("Region = %s (%s)%n", usLocale.getCountry(), usLocale.getDisplayCountry(Locale.FRENCH));
    }
    
    public static void demoToLanguageTag(){
        printHeading("Demo toLanguageTag()");
        Locale serbian = new Locale.Builder()
            .setLanguage("sr")
            .setScript("Cyrl")
            .setRegion("ME")
            .build();
        System.out.println(serbian.toLanguageTag());
    }

    public static void main(String[] args)
    {
        demoDefaults();
        demoConstructors();
        demoBuilder();
        demoForLanguageTag();
        demoConstants();
        demoAccessors();
        demoExtensionAccess();
        demoUnicodeExtensionAccess();
        demoDisplayXXX();
        demoGetAvailablelLocales();
        demoToLanguageTag();
    }
    
    private static void printHeading(String h)
    {
        StringBuilder sb = new StringBuilder("-");
        while (sb.length() < 80) {
            if (sb.length() * 2 > 80) {
                sb.append(sb.substring(0, 80 - sb.length()));
            } else {
                sb.append(sb);
            }
        }
        String sep = sb.toString();
        System.out.println(sep);
        System.out.println(h);
        System.out.println(sep);
    }
}
